==> Wx-0.20.tar.gz: Wx-0.20/cpp/scrolledwindow.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        scrolledwindow.h
// Purpose:     c++ wrapper for wxScrolledWindow
// Author:      Mattia Barbon
// Modified by:
// Created:      2/12/2000
// RCS-ID:      
// Copyright:   (c) 2000-2002 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

class wxPliScrolledWindow:public wxScrolledWindow
{
    WXPLI_DECLARE_DYNAMIC_CLASS( wxPliScrolledWindow );
    WXPLI_DECLARE_V_CBACK();
public:
    WXPLI_DEFAULT_CONSTRUCTOR( wxPliScrolledWindow, "Wx::ScrolledWindow",
                               TRUE );
    WXPLI_CONSTRUCTOR_6( wxPliScrolledWindow, "Wx::ScrolledWindow",
                         TRUE, wxWindow*, wxWindowID, const wxPoint&,
                         const wxSize&, long, const wxString& );

    void OnDraw( wxDC& dc );
};

void wxPliScrolledWindow::OnDraw( wxDC& dc )
{
    dTHX;
    if( wxPliVirtualCallback_FindCallback( aTHX_ &m_callback, "OnDraw" ) )
    {
        SV* val = wxPli_object_2_sv( aTHX_ newSViv( 0 ), &dc );
        wxPliVirtualCallback_CallCallback( aTHX_ &m_callback,
                                           G_SCALAR|G_DISCARD, "S", val );
        sv_setiv( SvRV( val ), 0 );
        SvREFCNT_dec( val );
    } else
        wxScrolledWindow::OnDraw( dc );
}

WXPLI_IMPLEMENT_DYNAMIC_CLASS( wxPliScrolledWindow, wxScrolledWindow );

// Local variables: //
// mode: c++ //
// End: //

==> Wx-0.21.tar.gz: Wx-0.21/cpp/scrolledwindow.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        cpp/scrolledwindow.h
// Purpose:     c++ wrapper for wxScrolledWindow
// Author:      Mattia Barbon
// Modified by:
// Created:     02/12/2000
// RCS-ID:      $Id: scrolledwindow.h,v 1.9 2004/08/04 20:13:55 mbarbon Exp $
// Copyright:   (c) 2000-2002 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

class wxPliScrolledWindow:public wxScrolledWindow
{
    WXPLI_DECLARE_DYNAMIC_CLASS( wxPliScrolledWindow );
    WXPLI_DECLARE_V_CBACK();
public:
    WXPLI_DEFAULT_CONSTRUCTOR( wxPliScrolledWindow, "Wx::ScrolledWindow",
                               true );
    WXPLI_CONSTRUCTOR_6( wxPliScrolledWindow, "Wx::ScrolledWindow",
                         true, wxWindow*, wxWindowID, const wxPoint&,
                         const wxSize&, long, const wxString& );

    void OnDraw( wxDC& dc );
};

void wxPliScrolledWindow::OnDraw( wxDC& dc )
{
    dTHX;
    if( wxPliVirtualCallback_FindCallback( aTHX_ &m_callback, "OnDraw" ) )
    {
        SV* val = wxPli_object_2_sv( aTHX_ newSViv( 0 ), &dc );
        wxPliVirtualCallback_CallCallback( aTHX_ &m_callback,
                                           G_SCALAR|G_DISCARD, "S", val );
        sv_setiv( SvRV( val ), 0 );
        SvREFCNT_dec( val );
    } else
        wxScrolledWindow::OnDraw( dc );
}

WXPLI_IMPLEMENT_DYNAMIC_CLASS( wxPliScrolledWindow, wxScrolledWindow );

// Local variables: //
// mode: c++ //
// End: //
